function varargout = gui1(varargin)
% GUI1 M-file for gui1.fig
%      GUI1, by itself, creates a new GUI1 or raises the existing
%      singleton*.
%
%      H = GUI1 returns the handle to a new GUI1 or the handle to
%      the existing singleton*.
%
%      GUI1('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in GUI1.M with the given input arguments.
%
%      GUI1('Property','Value',...) creates a new GUI1 or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before gui1_OpeningFcn gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to gui1_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Edit the above text to modify the response to help gui1

% Last Modified by GUIDE v2.5 27-Jul-2010 09:29:58

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @gui1_OpeningFcn, ...
                   'gui_OutputFcn',  @gui1_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before gui1 is made visible.
function gui1_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to gui1 (see VARARGIN)

% Choose default command line output for gui1
handles.output = hObject;

% Update handles structure
guidata(hObject, handles);

% UIWAIT makes gui1 wait for user response (see UIRESUME)
% uiwait(handles.figure1);


% --- Outputs from this function are returned to the command line.
function varargout = gui1_OutputFcn(hObject, eventdata, handles) 
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;


% --- Executes on button press in imagen.
function imagen_Callback(hObject, eventdata, handles)
imagen_video = mmreader('humo_chico.avi');
A=get (imagen_video);
frames=A.NumberOfFrames;

for i=1:frames
imagencolor=read(imagen_video,1);
%figure(1),imshow(imagencolor)
imagencolor2=read(imagen_video,i);

%figure(1),imshow(imagencolor2)

imagen_double = im2double(imagencolor);
imagen_double2 = im2double(imagencolor2);
imagen_resta=imagen_double2-imagen_double;
imagen_resta_gray =rgb2gray(imagen_resta);
level=graythresh(imagen_resta);
bw=im2bw(imagen_resta,level);

%figure(3),imshow(bw)
%figure(1),imshow(imagen_resta_gray)

%noDarkCar = imextendedmax(darkCar, darkCarValue);
%figure(3),imshow(imagen_resta_bw)

%figure, imshow(noDarkCar)
 %imagen_color=imread(imagen);
 %imagen_gray=rgb2gray(imagen_color);
 %figure(2)
 a=imhist(imagen_resta_gray);
 
 
 b=a(1:50);
 
 t=min(b);
 if t>15


     title('hay humo')
     %figure(2),imshow(imagen_resta_gray);
     imshow(imagencolor2)
     hold on
     imcontour(bw,1)
     
     
     
     
     
 else
    imshow(imagencolor2)
 end
 
end  


% hObject    handle to imagen (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)


% --- Executes on button press in pushbutton4.
function pushbutton4_Callback(hObject, eventdata, handles)
pause(inf);
% hObject    handle to pushbutton4 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)


% --- Executes on button press in pushbutton5.
function pushbutton5_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton5 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)


